-*- template-expand-function: template-tempo-expand -*-
<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title>(>>>(p "Document Title: " title)<<<)</title>
  </head>

  <body>
    <h1>(>>>(s title)<<<)</h1>

    (>>>POINT<<<)
    
  </body>
</html>
